@@ -1346,6 +1346,9 @@ goa_dav_client_discover (GoaDavClient        *self,
                                  (GAsyncReadyCallback) dav_client_discover_lookup_cb,
                                  g_object_ref (task));
     }
+
+  g_queue_push_tail (&discover->candidates,
+                     goa_dav_config_new (GOA_SERVICE_TYPE_WEBDAV, discover->uri, NULL));
 }
 
 /**
